@@ -11,7 +11,7 @@ Data::Chronicle::Writer - Provides writing to an efficient data storage for vola
 
 =cut
 
-our $VERSION = '0.13';    ## VERSION
+our $VERSION = '0.14';    ## VERSION
 
 =head1 DESCRIPTION
 
@@ -92,13 +92,32 @@ has 'ttl' => (
     default => undef,
 );
 
+=head2 publish_on_set
+
+Will invoke
+
+    $cache_writer->publish("$category::$name1", $value);
+
+if set to true. This is useful, if to provide redis or postgres notificaitons on new data.
+
+Default value: 0 (false)
+
+=cut
+
+has 'publish_on_set' => (
+    isa     => 'Int',
+    is      => 'ro',
+    default => sub { 0 },
+);
+
 =head2 set
 
 Example:
 
     $chronicle_writer->set("category1", "name1", $value1);
 
-Store a piece of data "value1" under key "category1::name1" in Pg and Redis.
+Store a piece of data "value1" under key "category1::name1" in Pg and Redis. Will
+publish "category1::name1" in Redis if C<publish_on_set> is true.
 
 =cut
 
@@ -118,10 +137,17 @@ sub set {
 
     $value = JSON::to_json($value);
 
-    my $key = $category . '::' . $name;
-    $self->cache_writer->set(
+    my $key    = $category . '::' . $name;
+    my $writer = $self->cache_writer;
+
+    # publish & set in transaction
+    $writer->multi;
+    $writer->publish($key, $value) if $self->publish_on_set;
+    $writer->set(
         $key => $value,
         $self->ttl ? ('EX' => $self->ttl) : ());
+    $writer->exec;
+
     $self->_archive($category, $name, $value, $rec_date) if $archive and $self->db_handle;
 
     return 1;
